"""
Library for encrypted python object serialization.

CryptPickle allows you to easily encrypt python objects into a file and decrypt,
regardless of their content.
It may be any python object, including for example a Pandas DataFrame.
"""


__version__ = "0.7"


import pickle
import string
import pyzipper

DATA_PATH = "./data.crypt"
NO_PASSWD = None


def obj_to_encrypted(obj, password=NO_PASSWD, path=DATA_PATH):
    """Encrypt object data to file"""
    buf = pickle.dumps(obj)
    pwd = password
    with pyzipper.AESZipFile(path,
                         'w',
                         compression=pyzipper.ZIP_DEFLATED,
                         encryption=pyzipper.WZ_AES) as zf:
        zf.setpassword(pwd.encode('utf-8'))
        zf.writestr('data', buf)


def obj_from_encrypted(password=NO_PASSWD, path=DATA_PATH):
    """Decrypt object data to file"""
    pwd = password
    with pyzipper.AESZipFile(path) as zf:
        zf.setpassword(pwd.encode('utf-8'))
        buf = zf.read('data')
    return pickle.loads(buf)



import cryptpickle
import pandas as pd

# Create a dictionary with some data
df1 = pd.DataFrame({'A': [1, 2, 3],
                   'B': ['one', 'one', 'four']})

# Print the data
print(df1)

# Serialice the data in an encrypted file (path) with a password (password)
cryptpickle.obj_to_encrypted(df1,password="SecretPassword",path='./pd_data.crypt')

# Load the serialiced data in other Pandas DataFrame.
df2 =cryptpickle.obj_from_encrypted(password="SecretPassword",path='./pd_data.crypt')

# Print the data
print(df2)


import cryptpickle

# Create a dictionary with some data
# It could be any other python object. ie: a Pandas Dataframe 
ej1 = { 'name1': 'John Doe',
        'name2': 'Lisa Doe'}

# Print the data
print(ej1)

# Serialice the data in an encrypted file with a password (file.crypt)
cryptpickle.obj_to_encrypted(ej1,password="SecretPassword",path='./file.crypt')

# Load the serialiced data in other python object. Password is needed to unencrypt the data
ej2 =cryptpickle.obj_from_encrypted(password="SecretPassword",path='./file.crypt')

# Print the data
print(ej2)